//Justin Louey Mechatronics Project
//Reads input from DHT Temperature Pin and depending on if it is hot or not, changes an rgb and speaker to indicate the user if their is danger of fire.
//Also displays temperature on LCD screen.

// DHT SETUP
#include <dht.h> // Include the DHT library
#define dht_dpin A0 // Tells the board that the DHT pin is in analog input 0
dht DHT; // dht = DHT

// LIQUID CRYSTAL SETUP
#include <LiquidCrystal.h>  // Include the Liquid Crystal library
LiquidCrystal lcd(8, 9, 4, 5, 6, 7); //Shorten to LCD / tells arduino which ports the lcd occupies

// DEFINING RGB + BUZZER
#define redpin 1 // Defines redpin of RGB in port 1
#define greenpin 2 // Defines greenpin of RGB in port 2
#define bluepin 3 // Defines bluepin of RGB in port 3
#define buzzerpin 10 // Defines buzzerpin in port 10

// VARIABLE/S
int temp = analogRead(DHT.temperature); // Establishes Integer "temp" which is the value from the DHT.temperature command

void setup() {

// OUTPUT/INPUT
analogWrite(redpin, OUTPUT); // Declare/define redpin as Output
analogWrite(greenpin, OUTPUT); // Declare/define greenpin as Output
analogWrite(bluepin, OUTPUT); // Declare/define bluepin as Output
pinMode(buzzerpin, OUTPUT); // Declare/define buzzerpin as Output

// LCD SCREEN
lcd.begin (16,2); // Define LCD screen as 16 columns and 2 rows
}

void loop() {

// LCD CODE WITHOUT VARIABILITY
DHT.read11(dht_dpin); // Read input from dht_dpin also (A0)
lcd.setCursor(0, 0); //Sets curser to Column 0, Row 0
lcd.print("It's "); //Writes "It's " on the LCD screen
lcd.print(DHT.temperature); // Prints the DHT.temperature value from DHT pin on column 0, Row 0
lcd.print(" "); // Prints a space after the temperature
lcd.print((char)223); // prints Degree sign after temperature
lcd.print("C"); // Prints a "c" after the degrees sign to symbolize celsius

// LCD FLASHING
lcd.setCursor(0, 1); // Sets curser to Column 0, Row 1
lcd.noDisplay();
lcd.print("No Fire Danger"); // Prints "No Chance of Fire"
lcd.noDisplay(); // Turns LCD display off (part of flash)
delay(1000);// Stays off for 1 second
lcd.display(); // Turns LCD display back on
delay(1000);// Stays on for 1 second

// RGB + BUZZER CODE
analogWrite(redpin, 0); // No output from red pin
analogWrite(greenpin, 255); // 255 output from greenpin (Makes RGB green)
analogWrite(bluepin, 0); // No output from blue pin
tone(buzzerpin, 20, 20); // // Emits Frequency of 20 hertz for 0.02 Seconds from buzzer

// IF TEMP IS 25-30
if ((int(DHT.temperature) >= 25.00) && (int(DHT.temperature) <= 30.00))
{
lcd.clear(); //Clears LCD Screen
lcd.setCursor(0, 1); //Sets curser to Column 0, Row 1
lcd.print("Small Alert"); // Prints "Small Alert" on Column 0, Row 1
lcd.noDisplay(); // Turns LCD display off (part of flash)
delay(1000);// Stays off for 1 second
lcd.display(); // Turns LCD display back on
delay(1000);// Stays on for 1 second
analogWrite(redpin, 255); // 255 output from redpin (Makes RGB yellow)
analogWrite(greenpin, 255); // 255 output from greenpin (Makes RGB yellow)
analogWrite(bluepin, 0); // No output from blue pin
tone(buzzerpin, 200, 100); // Emits Frequency of 200 hertz for 0.1 Seconds from buzzer

delay(300); // .3 Second delay

}
// IF TEMP IS 31-37
else if ((int(DHT.temperature) <= 31.00) && (int(DHT.temperature) >= 37.00))
{

lcd.clear(); //Clears LCD Screen
lcd.setCursor(0, 1); //Sets curser to Column 0, Row 1
lcd.print("Medium Alert"); // Prints "Medium Alert" on Column 0, Row 1
lcd.noDisplay(); // Turns LCD display off (part of flash)
delay(500);// Stays off for 0.5 second
lcd.display(); // Turns LCD display back on
delay(500);// Stays on for 0.5 second
analogWrite(redpin, 255); // 255 output from redpin (Makes RGB orange)
analogWrite(greenpin, 165); // 165 output from greenpin (Makes RGB orange)
analogWrite(bluepin, 0); // No output from bluepin
tone(buzzerpin, 500, 900); // Emits Frequency of 500 hertz for 0.9 Seconds from buzzer

delay(300); // .3 Second delay

}
// IF TEMP IS 38-100
else if ((int(DHT.temperature) <= 38.00) && (int(DHT.temperature) >= 100.00))
{

lcd.clear(); //Clears LCD Screen
lcd.setCursor(0, 1); //Sets curser to Column 0, Row 1
lcd.print("Call 000"); // Prints "Call 000" on Column 0, Row 1
lcd.noDisplay(); // Turns LCD display off (part of flash)
delay(250);// Stays off for 0.25 second
lcd.display(); // Turns LCD display back on
delay(250);// Stays on for 0.25 second
analogWrite(redpin, 255); // 255 output from redpin (Makes RGB red)
analogWrite(greenpin, 0); // No output from greenpin
analogWrite(bluepin, 0); // No output from bluepin
tone(buzzerpin, 1000, 900); // Emits Frequency of 1000 hertz for 0.9 Seconds from buzzer

delay(300); // .3 Second delay

}}
